@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -13,33 +13,27 @@
 __docformat__ = 'restructuredtext'
 
 import logging
+
 lgr = logging.getLogger('datalad.interface.base')
 
 import os
-import sys
 import re
 import textwrap
-from importlib import import_module
-import inspect
-import string
-from collections import (
-    defaultdict,
-    OrderedDict,
-)
 import warnings
-
-from ..ui import ui
-
-from datalad.interface.common_opts import eval_params
-from datalad.interface.common_opts import eval_defaults
-from datalad.support.constraints import (
-    EnsureKeyChoice,
-    EnsureChoice,
+from abc import (
+    ABC,
+    abstractmethod,
 )
-from datalad.distribution.dataset import Dataset
-from datalad.distribution.dataset import resolve_path
-from datalad.support.exceptions import CapturedException
+from collections import OrderedDict
+from importlib import import_module
 
+import datalad
+from datalad.distribution.dataset import (
+    Dataset,
+    resolve_path,
+)
+from datalad.interface.common_opts import eval_params
+from datalad.support.exceptions import CapturedException
 
 default_logchannels = {
     '': 'debug',
@@ -59,15 +53,6 @@ def get_api_name(intfspec):
     return name
 
 
-def get_cmdline_command_name(intfspec):
-    """Given an interface specification return a cmdline command name"""
-    if len(intfspec) > 2:
-        name = intfspec[2]
-    else:
-        name = intfspec[0].split('.')[-1].replace('_', '-')
-    return name
-
-
 def get_interface_groups(include_plugins=False):
     """Return a list of command groups.
 
@@ -111,7 +96,7 @@ def get_cmd_summaries(descriptions, groups, width=79):
     group is preceded by an entry describing the group.
     """
     cmd_summary = []
-    for grp in sorted(groups, key=lambda x: x[1]):
+    for grp in sorted(groups, key=lambda x: x[0]):
         grp_descr = grp[1]
         grp_cmds = descriptions[grp[0]]
 
@@ -167,19 +152,6 @@ def get_cmd_doc(interface):
     return intf_doc
 
 
-def get_cmd_ex(interface):
-    """Return the examples for the command defined by 'interface'.
-
-    Parameters
-    ----------
-    interface : subclass of Interface
-    """
-    intf_ex = "\n\n*Examples*\n\n"
-    for example in interface._examples_:
-        intf_ex += build_example(example, api='cmdline')
-    return intf_ex
-
-
 def dedent_docstring(text):
     """Remove uniform indentation from a multiline docstring"""
     # Problem is that first line might often have no offset, so might
@@ -221,6 +193,11 @@ def alter_interface_docs_for_api(docs):
         lambda match: match.group(1),
         docs,
         flags=re.MULTILINE)
+    # select only the python alternative from argument specifications
+    docs = re.sub(
+        r'``([a-zA-Z0-9_,.]+)\|\|([a-zA-Z0-9-,.]+)``',
+        lambda match: f'``{match.group(1)}``',
+        docs)
     docs = re.sub(
         r'\|\| PYTHON \>\>(.*?)\<\< PYTHON \|\|',
         lambda match: match.group(1),
@@ -240,82 +217,8 @@ def alter_interface_docs_for_api(docs):
             '\\1 (http://handbook.datalad.org/symbols)',
             docs)
     docs = re.sub(
-        r'\|\| REFLOW \>\>\n(.*?)\<\< REFLOW \|\|',
-        lambda match: textwrap.fill(match.group(1)),
-        docs,
-        flags=re.MULTILINE | re.DOTALL)
-    return docs
-
-
-def alter_interface_docs_for_cmdline(docs):
-    """Apply modifications to interface docstrings for cmdline doc use."""
-    # central place to alter the impression of docstrings,
-    # like removing Python API specific sections, and argument markup
-    if not docs:
-        return docs
-    docs = dedent_docstring(docs)
-    # clean cmdline sections
-    docs = re.sub(
-        r'\|\| PYTHON \>\>.*?\<\< PYTHON \|\|',
-        '',
-        docs,
-        flags=re.MULTILINE | re.DOTALL)
-    # clean cmdline in-line bits
-    docs = re.sub(
-        r'\[PY:\s[^\[\]]*\sPY\]',
-        '',
-        docs,
-        flags=re.MULTILINE | re.DOTALL)
-    docs = re.sub(
-        r'\[CMD:\s([^\[\]]*)\sCMD\]',
-        lambda match: match.group(1),
-        docs,
-        flags=re.MULTILINE)
-    docs = re.sub(
-        r'\|\| CMDLINE \>\>(.*?)\<\< CMDLINE \|\|',
-        lambda match: match.group(1),
-        docs,
-        flags=re.MULTILINE | re.DOTALL)
-    # remove :role:`...` RST markup for cmdline docs
-    docs = re.sub(
-        r':\S+:`[^`]*`[\\]*',
-        lambda match: ':'.join(match.group(0).split(':')[2:]).strip('`\\'),
-        docs,
-        flags=re.MULTILINE | re.DOTALL)
-    # make the handbook doc references more accessible
-    # the URL is a redirect configured at readthedocs
-    docs = re.sub(
-        r'(handbook:[0-9]-[0-9]*)',
-        '\\1 (http://handbook.datalad.org/symbols)',
-        docs)
-    # remove None constraint. In general, `None` on the cmdline means don't
-    # give option at all, but specifying `None` explicitly is practically
-    # impossible
-    docs = re.sub(
-        r',\sor\svalue\smust\sbe\s`None`',
-        '',
-        docs,
-        flags=re.MULTILINE | re.DOTALL)
-    # capitalize variables and remove backticks to uniformize with
-    # argparse output
-    docs = re.sub(
-        r'`\S*`',
-        lambda match: match.group(0).strip('`').upper(),
-        docs)
-    # clean up sphinx API refs
-    docs = re.sub(
-        r'\~datalad\.api\.\S*',
-        lambda match: "`{0}`".format(match.group(0)[13:]),
-        docs)
-    # Remove RST paragraph markup
-    docs = re.sub(
-        r'^.. \S+::',
-        lambda match: match.group(0)[3:-2].upper(),
-        docs,
-        flags=re.MULTILINE)
-    docs = re.sub(
-        r'\|\| REFLOW \>\>\n(.*?)\<\< REFLOW \|\|',
-        lambda match: textwrap.fill(match.group(1)),
+        r'^([ ]*)\|\| REFLOW \>\>\n(.*?)\<\< REFLOW \|\|',
+        lambda match: textwrap.fill(match.group(2), subsequent_indent=match.group(1)),
         docs,
         flags=re.MULTILINE | re.DOTALL)
     return docs
@@ -337,9 +240,9 @@ def update_docstring_with_parameters(func, params, prefix=None, suffix=None,
     the number and names of the callables arguments.
     """
     from datalad.utils import getargspec
+
     # get the signature
-    ndefaults = 0
-    args, varargs, varkw, defaults = getargspec(func)
+    args, varargs, varkw, defaults = getargspec(func, include_kwonlyargs=True)
     defaults = defaults or tuple()
     if add_args:
         add_argnames = sorted(add_args.keys())
@@ -381,6 +284,8 @@ def update_docstring_with_parameters(func, params, prefix=None, suffix=None,
     return func
 
 
+# TODO should export code_field and indicator, rather than have modes
+# TODO this should be a doc helper
 def build_example(example, api='python'):
     """Build a code example.
 
@@ -439,9 +344,12 @@ def update_docstring_with_examples(cls_doc, ex):
     Take _examples_ of a command, build the Python examples, and append
     them to the docstring.
 
-    cls_doc: docstring
+    Parameters
+    ----------
+    cls_doc: str
+      docstring
     ex: list
-        list of dicts with examples
+      list of dicts with examples
     """
     from textwrap import indent
     if len(cls_doc):
@@ -468,8 +376,11 @@ def build_doc(cls, **kwargs):
     Parameters
     ----------
     cls: Interface
-      class defining a datalad command
+      DataLad command implementation
     """
+    if datalad.in_librarymode():
+        lgr.debug("Not assembling DataLad API docs in libary-mode")
+        return cls
 
     # Note, that this is a class decorator, which is executed only once when the
     # class is imported. It builds the docstring for the class' __call__ method
@@ -484,7 +395,7 @@ def build_doc(cls, **kwargs):
     # would need to actually call the command once in order to build this
     # docstring.
 
-    lgr.debug("Building doc for {}".format(cls))
+    lgr.debug("Building doc for %s", cls)
 
     cls_doc = cls.__doc__
     if hasattr(cls, '_docs_'):
@@ -508,7 +419,9 @@ def build_doc(cls, **kwargs):
     if not _has_eval_results_call(cls):
         add_args = None
     else:
-        add_args = {k: getattr(cls, k, v) for k, v in eval_defaults.items()}
+        # defaults for all common parameters are guaranteed to be available
+        # from the class
+        add_args = {k: getattr(cls, k) for k in eval_params}
 
     # ATTN: An important consequence of this update() call is that it
     # fulfills the docstring's promise of overriding any existing
@@ -525,298 +438,152 @@ def build_doc(cls, **kwargs):
         add_args=add_args
     )
 
+    if hasattr(cls.__call__, '_dataset_method'):
+        cls.__call__._dataset_method.__doc__ = cls.__call__.__doc__
+
     # return original
     return cls
 
 
-NA_STRING = 'N/A'  # we might want to make it configurable via config
+class Interface(ABC):
+    '''Abstract base class for DataLad command implementations
 
+    Any DataLad command implementation must be derived from this class. The
+    code snippet below shows a complete sketch of a Python class with such an
+    implementation.
 
-class nagen(object):
-    """A helper to provide a desired missing value if no value is known
+    Importantly, no instances of command classes will created. Instead the main
+    entry point is a static ``__call__()`` method, which must be implemented
+    for any command. It is incorporated as a function in :mod:`datalad.api`, by
+    default under the name of the file the implementation resides (e.g.,
+    ``command`` for a ``command.py`` file).  Therefore the file should have a
+    name that is a syntax-compliant function name. The default naming rule can
+    be overwritten with an explicit alternative name (see
+    :func:`datalad.interface.base.get_api_name`).
 
-    Usecases
-    - could be used as a generator for `defaultdict`
-    - since it returns itself upon getitem, should work even for complex
-      nested dictionaries/lists .format templates
-    """
-    def __init__(self, missing=NA_STRING):
-        self.missing = missing
+    For commands implementing functionality that is operating on DataLad
+    datasets, a command can be also be bound to the
+    :class:`~datalad.distribution.dataset.Dataset` class as a method using
+    the ``@datasetmethod`` decorator, under the specified name.
 
-    def __repr__(self):
-        cls = self.__class__.__name__
-        args = str(self.missing) if self.missing != NA_STRING else ''
-        return '%s(%s)' % (cls, args)
+    Any ``__call__()`` implementation should be decorated with
+    :func:`datalad.interface.utils.eval_results`. This adds support for
+    standard result processing, and a range of common command parameters that
+    do not need to be manually added to the signature of ``__call__()``. Any
+    implementation decorated in this way should be implemented as a generator,
+    and ``yield`` :ref:`result records <chap_design_result_records>`.
 
-    def __str__(self):
-        return self.missing
+    Any argument or keyword argument that appears in the signature of
+    ``__call__()`` must have a matching item in :attr:`Interface._params_`.
+    The dictionary maps argument names to
+    :class:`datalad.support.param.Parameter` specifications. The specification
+    contain CLI argument declarations, value constraint and data type
+    conversation specifications, documentation, and optional
+    ``argparse``-specific arguments for CLI parser construction.
 
-    def __getitem__(self, *args):
-        return self
+    The class decorator :func:`datalad.interface.base.build_doc` inspects an
+    :class:`Interface` implementation, and builds a standard docstring from
+    various sources of structured information within the class (also see
+    below). The documentation is automatically tuned differently, depending on
+    the target API (Python vs CLI).
 
-    def __getattr__(self, item):
-        return self
+    .. code:: python
 
+        @build_doc
+        class ExampleCommand(Interface):
+            """SHORT DESCRIPTION
 
-def nadict(*items):
-    """A generator of default dictionary with the default nagen"""
-    dd = defaultdict(nagen)
-    dd.update(*items)
-    return dd
+            LONG DESCRIPTION
+            ...
+            """
 
+            # COMMAND PARAMETER DEFINITIONS
+            _params_ = dict(
+                example=Parameter(
+                    args=("--example",),
+                    doc="""Parameter description....""",
+                    constraints=...),
+                ...
+                )
+            )
 
-class DefaultOutputFormatter(string.Formatter):
-    """A custom formatter for default output rendering using .format
-    """
-    # TODO: make missing configurable?
-    def __init__(self, missing=nagen()):
-        """
-        Parameters
-        ----------
-        missing: string, optional
-          What to output for the missing values
-        """
-        super(DefaultOutputFormatter, self).__init__()
-        self.missing = missing
+            # RESULT PARAMETER OVERRIDES
+            return_type= 'list'
+            ...
 
-    def _d(self, msg, *args):
-        # print("   HERE %s" % (msg % args))
-        pass
+            # USAGE EXAMPLES
+            _examples_ = [
+                dict(text="Example description...",
+                     code_py="Example Python code...",
+                     code_cmd="Example shell code ..."),
+                ...
+            ]
 
-    def get_value(self, key, args, kwds):
-        assert not args
-        self._d("get_value: %r %r %r", key, args, kwds)
-        return kwds.get(key, self.missing)
+            @staticmethod
+            @datasetmethod(name='example_command')
+            @eval_results
+            def __call__(example=None, ...):
+                ...
 
-    # def get_field(self, field_name, args, kwds):
-    #     assert not args
-    #     self._d("get_field: %r args=%r kwds=%r" % (field_name, args, kwds))
-    #     try:
-    #         out = string.Formatter.get_field(self, field_name, args, kwds)
-    #     except Exception as exc:
-    #         # TODO needs more than just a value
-    #         return "!ERR %s" % exc
+                yield dict(...)
 
+    The basic implementation setup described above can be customized for
+    individual commands in various way that alter the behavior and
+    presentation of a specific command. The following overview uses
+    the code comment markers in the above snippet to illustrate where
+    in the class implementation these adjustments can be made.
 
-class DefaultOutputRenderer(object):
-    """A default renderer for .format'ed output line
-    """
-    def __init__(self, format):
-        self.format = format
-        # We still need custom output formatter since at the "first level"
-        # within .format template all items there is no `nadict`
-        self.formatter = DefaultOutputFormatter()
+    (SHORT/LONG) DESCRIPTION
 
-    @classmethod
-    def _dict_to_nadict(cls, v):
-        """Traverse datastructure and replace any regular dict with nadict"""
-        if isinstance(v, list):
-            return [cls._dict_to_nadict(x) for x in v]
-        elif isinstance(v, dict):
-            return nadict((k, cls._dict_to_nadict(x)) for k, x in v.items())
-        else:
-            return v
+    ``Interface.short_description`` can be defined to provide an
+    explicit short description to be used in documentation and help output,
+    replacing the auto-generated extract from the first line of the full
+    description.
 
-    def __call__(self, x, **kwargs):
-        dd = nadict(
-            (k, nadict({k_.replace(':', '#'): self._dict_to_nadict(v_)
-                for k_, v_ in v.items()})
-                if isinstance(v, dict) else v)
-            for k, v in x.items()
-        )
+    COMMAND PARAMETER DEFINITIONS
 
-        msg = self.formatter.format(self.format, **dd)
-        return ui.message(msg)
+    When a parameter specification declares ``Parameter(args=tuple(), ...)``,
+    i.e. no arguments specified, it will be ignored by the CLI. Likewise, any
+    ``Parameter`` specification for which :func:`is_api_arg` returns ``False``
+    will also be ignored by the CLI. Additionally, any such parameter will
+    not be added to the parameter description list in the Python docstring.
 
+    RESULT PARAMETER OVERRIDES
 
-class Interface(object):
-    """Base class for interface implementations"""
+    The :func:`datalad.interface.utils.eval_results` decorator automatically
+    add a range of additional arguments to a command, which are defined in
+    :py:data:`datalad.interface.common_opts.eval_params`. For any such
+    parameter an Interface implementation can define an interface-specific
+    default value, by declaring a class member with the respective parameter
+    name and the desired default as its assigned value. This feature can be
+    used to tune the default command behavior, for example, with respect to the
+    default result rendering style, or its error behavior.
 
-    # exit code to return if user-interrupted
-    # if None, would just reraise the Exception, so if in --dbg
-    # mode would fall into the debugger
-    _interrupted_exit_code = 1
+    In addition to the common parameters of the Python API, an additional
+    ``Interface.result_renderer_cmdline`` can be defined, in order to
+    instruct the CLI to prefer the specified alternative result renderer
+    over an ``Interface.result_renderer`` specification.
 
-    @classmethod
-    def setup_parser(cls, parser):
-        # XXX needs safety check for name collisions
-        # XXX allow for parser kwargs customization
-        parser_kwargs = {}
-        from datalad.utils import getargspec
-        # get the signature
-        ndefaults = 0
-        args, varargs, varkw, defaults = getargspec(cls.__call__)
-        if defaults is not None:
-            ndefaults = len(defaults)
-        default_offset = ndefaults - len(args)
-        prefix_chars = parser.prefix_chars
-        for i, arg in enumerate(args):
-            if not is_api_arg(arg):
-                continue
-            param = cls._params_[arg]
-            defaults_idx = default_offset + i
-            cmd_args = param.cmd_args
-            if cmd_args == tuple():
-                # explicitly provided an empty sequence of argument names
-                # this shall not appear in the parser
-                continue
+    USAGE EXAMPLES
 
-            parser_kwargs = param.cmd_kwargs
-            has_default = defaults_idx >= 0
-            if cmd_args:
-                if cmd_args[0][0] in prefix_chars:
-                    # TODO: All the Parameter(args=...) values in this code
-                    # base use hyphens, so there is no point in the below
-                    # conversion. If it looks like no extensions rely on this
-                    # behavior either, this could be dropped.
-                    parser_args = [c.replace('_', '-') for c in cmd_args]
-                else:
-                    # Argparse will not convert dashes to underscores for
-                    # arguments that don't start with a prefix character, so
-                    # the above substitution must be avoided so that
-                    # call_from_parser() can find the corresponding parameter.
-                    parser_args = cmd_args
-            elif has_default:
-                # Construct the option from the Python parameter name.
-                parser_args = ("--{}".format(arg.replace("_", "-")),)
-            else:
-                # If args= wasn't given and its a positional argument in the
-                # function, add a positional argument to argparse. If `dest` is
-                # specified, we need to remove it from the keyword arguments
-                # because add_argument() expects it as the first argument. Note
-                # that `arg` shouldn't have a dash here, but `metavar` can be
-                # used if a dash is preferred for the command-line help.
-                parser_args = (parser_kwargs.pop("dest", arg),)
+    Any number of usage examples can be described in an ``_examples_`` list
+    class attribute. Such an example contains a description, and code examples
+    for Python and CLI.
+    '''
+    _params_ = {}
 
-            if has_default:
-                parser_kwargs['default'] = defaults[defaults_idx]
-            help = alter_interface_docs_for_cmdline(param._doc)
-            if help and help.rstrip()[-1] != '.':
-                help = help.rstrip() + '.'
-            if param.constraints is not None:
-                parser_kwargs['type'] = param.constraints
-                # include value constraint description and default
-                # into the help string
-                cdoc = alter_interface_docs_for_cmdline(
-                    param.constraints.long_description())
-                if cdoc[0] == '(' and cdoc[-1] == ')':
-                    cdoc = cdoc[1:-1]
-                help += '  Constraints: %s' % cdoc
-                if 'metavar' not in parser_kwargs and \
-                        isinstance(param.constraints, EnsureChoice):
-                    parser_kwargs['metavar'] = \
-                        '{%s}' % '|'.join(
-                            # don't use short_description(), because
-                            # it also needs to give valid output for
-                            # Python syntax (quotes...), but here we
-                            # can simplify to shell syntax where everything
-                            # is a string
-                            p for p in param.constraints._allowed
-                            # in the cmdline None pretty much means
-                            # don't give the options, so listing it
-                            # doesn't make sense. Moreover, any non-string
-                            # value cannot be given and very likely only
-                            # serves a special purpose in the Python API
-                            # or implementation details
-                            if isinstance(p, str))
-            if defaults_idx >= 0:
-                # if it is a flag, in commandline it makes little sense to show
-                # showing the Default: (likely boolean).
-                #   See https://github.com/datalad/datalad/issues/3203
-                if not parser_kwargs.get('action', '').startswith('store_'):
-                    # [Default: None] also makes little sense for cmdline
-                    if defaults[defaults_idx] is not None:
-                        help += " [Default: %r]" % (defaults[defaults_idx],)
-            # create the parameter, using the constraint instance for type
-            # conversion
-            parser.add_argument(*parser_args, help=help,
-                                **parser_kwargs)
-
-    @classmethod
-    def call_from_parser(cls, args):
-        # XXX needs safety check for name collisions
-        from datalad.utils import getargspec
-        argspec = getargspec(cls.__call__)
-        if argspec[2] is None:
-            # no **kwargs in the call receiver, pull argnames from signature
-            argnames = getargspec(cls.__call__)[0]
-        else:
-            # common options
-            # XXX define or better get from elsewhere
-            common_opts = ('change_path', 'common_debug', 'common_idebug', 'func',
-                           'help', 'log_level', 'logger', 'pbs_runner',
-                           'result_renderer', 'subparser')
-            argnames = [name for name in dir(args)
-                        if not (name.startswith('_') or name in common_opts)]
-        kwargs = {k: getattr(args, k)
-                  for k in argnames
-                  # some arguments might be Python-only and do not appear in the
-                  # parser Namespace
-                  if hasattr(args, k) and is_api_arg(k)}
-        # we are coming from the entry point, this is the toplevel command,
-        # let it run like generator so we can act on partial results quicker
-        # TODO remove following condition test when transition is complete and
-        # run indented code unconditionally
-        if _has_eval_results_call(cls):
-            # set all common args explicitly  to override class defaults
-            # that are tailored towards the the Python API
-            kwargs['return_type'] = 'generator'
-            kwargs['result_xfm'] = None
-            # allow commands to override the default, unless something other than
-            # default is requested
-            kwargs['result_renderer'] = \
-                args.common_output_format if args.common_output_format != 'tailored' \
-                else getattr(cls, 'result_renderer', 'default')
-            if '{' in args.common_output_format:
-                # stupid hack, could and should become more powerful
-                kwargs['result_renderer'] = DefaultOutputRenderer(args.common_output_format)
-
-            if args.common_on_failure:
-                kwargs['on_failure'] = args.common_on_failure
-            # compose filter function from to be invented cmdline options
-            res_filter = cls._get_result_filter(args)
-            if res_filter is not None:
-                # Don't add result_filter if it's None because then
-                # eval_results can't distinguish between --report-{status,type}
-                # not specified via the CLI and None passed via the Python API.
-                kwargs['result_filter'] = res_filter
-        try:
-            ret = cls.__call__(**kwargs)
-            if inspect.isgenerator(ret):
-                ret = list(ret)
-            return ret
-        except KeyboardInterrupt as exc:
-            ui.error("\nInterrupted by user while doing magic: %s"
-                     % CapturedException(exc))
-            if cls._interrupted_exit_code is not None:
-                sys.exit(cls._interrupted_exit_code)
-            else:
-                raise
-
-    @classmethod
-    def _get_result_filter(cls, args):
-        from datalad import cfg
-        result_filter = None
-        if args.common_report_status or 'datalad.runtime.report-status' in cfg:
-            report_status = args.common_report_status or \
-                            cfg.obtain('datalad.runtime.report-status')
-            if report_status == "all":
-                pass  # no filter
-            elif report_status == 'success':
-                result_filter = EnsureKeyChoice('status', ('ok', 'notneeded'))
-            elif report_status == 'failure':
-                result_filter = EnsureKeyChoice('status',
-                                                ('impossible', 'error'))
-            else:
-                result_filter = EnsureKeyChoice('status', (report_status,))
-        if args.common_report_type:
-            tfilt = EnsureKeyChoice('type', tuple(args.common_report_type))
-            result_filter = result_filter & tfilt if result_filter else tfilt
-        return result_filter
+    @abstractmethod
+    def __call__():
+        """Must be implemented by any command"""
 
+    # https://github.com/datalad/datalad/issues/6376
     @classmethod
     def get_refds_path(cls, dataset):
-        """Return a resolved reference dataset path from a `dataset` argument"""
+        """Return a resolved reference dataset path from a `dataset` argument
+
+        .. deprecated:: 0.16
+           Use ``require_dataset()`` instead.
+        """
         # theoretically a dataset could come in as a relative path -> resolve
         if dataset is None:
             return dataset
@@ -827,15 +594,26 @@ class Interface(object):
         return refds_path
 
 
+# pull all defaults from all eval_results() related parameters and assign them
+# as attributes to the class, which then becomes the one place to query for
+# default and potential overrides
+for k, p in eval_params.items():
+    setattr(Interface,
+            # name is always given
+            k,
+            # but there may be no default (rather unlikely, though)
+            p.cmd_kwargs.get('default', None))
+
+
 def get_allargs_as_kwargs(call, args, kwargs):
-    """Generate a kwargs dict from a call signature and *args, **kwargs
+    """Generate a kwargs dict from a call signature and ``*args``, ``**kwargs``
 
     Basically resolving the argnames for all positional arguments, and
     resolving the defaults for all kwargs that are not given in a kwargs
     dict
     """
     from datalad.utils import getargspec
-    argspec = getargspec(call)
+    argspec = getargspec(call, include_kwonlyargs=True)
     defaults = argspec.defaults
     nargs = len(argspec.args)
     defaults = defaults or []  # ensure it is a list and not None
@@ -856,6 +634,8 @@ def get_allargs_as_kwargs(call, args, kwargs):
     return kwargs_
 
 
+# Only needed to support command implementations before the introduction
+# of @eval_results
 def _has_eval_results_call(cls):
     """Return True if cls has a __call__ decorated with @eval_results
     """
