@@ -9,18 +9,13 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Test metadata extraction"""
 
-from os.path import (
-    dirname,
-    join as opj,
-)
-
+from os.path import dirname
+from os.path import join as opj
 from shutil import copy
 
-from datalad.coreapi import Dataset
 from datalad.api import extract_metadata
-from datalad.utils import chpwd
-
-from datalad.tests.utils import (
+from datalad.coreapi import Dataset
+from datalad.tests.utils_pytest import (
     assert_in,
     assert_raises,
     assert_repo_status,
@@ -29,13 +24,13 @@ from datalad.tests.utils import (
     skip_if_no_module,
     with_tempfile,
 )
-
+from datalad.utils import chpwd
 
 testpath = opj(dirname(dirname(dirname(__file__))), 'metadata', 'tests', 'data', 'xmp.pdf')
 
 
 @with_tempfile(mkdir=True)
-def test_error(path):
+def test_error(path=None):
     # go into virgin dir to avoid detection of any dataset
     with chpwd(path):
         assert_raises(ValueError, extract_metadata, types=['bogus__'], files=[testpath])
@@ -43,7 +38,7 @@ def test_error(path):
 
 @known_failure_githubci_win
 @with_tempfile(mkdir=True)
-def test_ds_extraction(path):
+def test_ds_extraction(path=None):
     skip_if_no_module('libxmp')
 
     ds = Dataset(path).create()
@@ -79,7 +74,7 @@ def test_ds_extraction(path):
 
 @known_failure_githubci_win
 @with_tempfile(mkdir=True)
-def test_file_extraction(path):
+def test_file_extraction(path=None):
     skip_if_no_module('libxmp')
 
     # go into virgin dir to avoid detection of any dataset
