@@ -299,7 +299,7 @@ class EnsureChoice(Constraint):
 
     def __call__(self, value):
         if value not in self._allowed:
-            raise ValueError("value is not one of %s" % (self._allowed,))
+            raise ValueError(f"value {value} is not one of {self._allowed}")
         return value
 
     def long_description(self):
