@@ -12,10 +12,14 @@ import sys
 import unittest.mock
 from subprocess import TimeoutExpired
 
+import pytest
+
 from datalad.cmd import (
     BatchedCommand,
     readline_rstripped,
 )
+from datalad.cmd import BatchedCommandError
+from datalad.runner.exception import CommandError
 from datalad.runner.tests.utils import py2cmd
 from datalad.tests.utils_pytest import (
     assert_equal,
@@ -148,8 +152,9 @@ def test_batched_restart():
 
 
 def test_command_fail_1():
-    # Expect that the return code of a failing command is caught,
-    # that None is returned as result.
+    # Expect that a failing command raises a CommandError in which the return
+    # code and the last successful request is caught, and that the command is
+    # restarted when called again
     bc = BatchedCommand(
         cmd=py2cmd(
             """
@@ -158,19 +163,26 @@ exit(3)
             """))
 
     # Send something to start the process
-    result = bc("line one")
-    assert_equal(bc.return_code, None)
-    assert_equal(result, "something")
-    result = bc("line two")
-    assert_equal(bc.return_code, 3)
-    assert_equal(result, None)
+    first_request = "line one"
+    result = bc(first_request)
+    assert bc.return_code is None
+    assert result == "something"
+    with pytest.raises(BatchedCommandError) as exception_info:
+        bc("line two")
+    assert exception_info.value.code == 3
+    assert exception_info.value.last_processed_request == first_request
+    assert bc.return_code == 3
+
+    # Check for restart
+    result = bc(first_request)
+    assert result == "something"
     bc.close(return_stderr=False)
 
 
 def test_command_fail_2():
-    # Expect that the return code of a failing command is caught,
-    # that None is returned as result and that the process is restarted,
-    # if the batched command is called again.
+    # Expect that a failing command raises a BatchedCommandError in which the
+    # return code and the last successful request is caught. In this case the
+    # last successful request should be None.
     bc = BatchedCommand(
         cmd=py2cmd(
             """
@@ -178,10 +190,11 @@ print(a*b)
             """))
 
     # Send something to start the process
-    result = bc("line one")
-    assert_not_equal(bc.return_code, 0)
-    assert_is_none(result)
-    result = bc("line two")
-    assert_not_equal(bc.return_code, 0)
-    assert_is_none(result)
+    first_request = "line one"
+    with pytest.raises(BatchedCommandError) as exception_info:
+        _ = bc(first_request)
+    assert exception_info.value.code == 1
+    assert exception_info.value.last_processed_request is None
+    assert bc.return_code == 1
+    assert bc.last_request is None
     bc.close(return_stderr=False)
